OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "資料搬移中，請耐心等候直到資料搬移結束",
    "Migration started …" : "開始遷移…",
    "Saved" : "已儲存",
    "Not saved" : "未儲存",
    "Sending…" : "傳送中…",
    "Email sent" : "Email 已寄出",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "發生錯誤，請您上傳 ASCII 編碼的 PEM 憑證",
    "Valid until {date}" : "{date} 前有效",
    "Delete" : "刪除",
    "Local" : "本地",
    "Private" : "私人的",
    "Only visible to local users" : "僅本地用戶可見",
    "Only visible to you" : "僅你可見",
    "Contacts" : "聯絡人",
    "Visible to local users and to trusted servers" : "僅本地用戶與信任的伺服器可見",
    "Public" : "公開",
    "Will be synced to a global and public address book" : "將會同步到全域公開的通訊錄",
    "Verify" : "驗證",
    "Verifying …" : "驗證中…",
    "Unable to change password" : "無法修改密碼",
    "Very weak password" : "密碼強度非常弱",
    "Weak password" : "密碼強度弱",
    "So-so password" : "密碼強度普通",
    "Good password" : "密碼強度佳",
    "Strong password" : "密碼強度極佳",
    "Select a profile picture" : "選擇大頭貼照",
    "Groups" : "群組",
    "{actor} removed you from group {group}" : "{actor} 將你從 {group} 群組中移除",
    "{actor} changed your password" : "{actor} 變更了您的密碼",
    "You changed your password" : "您已變更您的密碼",
    "Your password was reset by an administrator" : "您的密碼已被管理員重設",
    "{actor} changed your email address" : "{actor} 變更了您的電子郵件地址",
    "You changed your email address" : "您已更改您的電子郵件地址",
    "Your email address was changed by an administrator" : "您的電子郵件已被管理員變更",
    "Security" : "安全性",
    "You successfully logged in using two-factor authentication (%1$s)" : "你已成功使用兩步驟驗證進行登入 (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "使用兩步驟驗證登入失敗 (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "你的 <strong>密碼</strong> 或 <strong>email</strong> 已更動。",
    "Couldn't remove app." : "無法移除應用程式",
    "Couldn't update app." : "無法更新應用程式",
    "Wrong password" : "密碼錯誤",
    "No user supplied" : "未提供使用者",
    "Authentication error" : "認證錯誤",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "請提供一個admin管理者恢復密碼，否則將會失去所有使用者資料。",
    "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理者還原密碼",
    "Backend doesn't support password change, but the user's encryption key was updated." : "使用者資料後端不支援變更密碼，但使用者的加密金鑰已經更新。",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "透過應用程式中心或是聯盟式雲端分享來安裝、更新應用程式",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "Invalid SMTP password." : "無效的 SMTP 密碼",
    "Email setting test" : "測試郵件設定",
    "Well done, %s!" : "太棒了， %s!",
    "If you received this email, the email configuration seems to be correct." : "如果你收到這封 email，代表 email 設定是正確的。",
    "Email could not be sent. Check your mail server log" : "郵件無法寄出，請查閱郵件伺服器記錄檔",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "寄出郵件時發生問題，請檢查您的設定（錯誤訊息：%s）",
    "You need to set your user email before being able to send test emails." : "在寄出測試郵件前您需要設定信箱位址",
    "Invalid mail address" : "無效的 email 地址",
    "Settings saved" : "設定已儲存",
    "Unable to change full name" : "無法變更全名",
    "Unable to change email address" : "無法變更電子郵件地址",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "為了驗證您的推特帳號，請在推特上發佈下列推文（請確認推文內容沒有斷行）：",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "為了驗證您的網站，請將下列內容存至您網站的根目錄下路徑為：\".well-known/CloudIdVerificationCode.txt\" 的檔案（請確保全文以一行的格式儲存）",
    "%1$s changed your password on %2$s." : "%1$s 在 %2$s 時更改了您的密碼",
    "Your password on %s was changed." : "你在 %s 的密碼已變更",
    "Your password on %s was reset by an administrator." : "您在 %s 的密碼已被管理員重設",
    "Password for %1$s changed on %2$s" : "%1$s 在 %2$s 的密碼已變更",
    "Password changed for %s" : "%s 的密碼已變更",
    "If you did not request this, please contact an administrator." : "如果你未發送此請求 ，請聯絡系統管理員",
    "Your email address on %s was changed." : "您在 %s 的電子郵件地址已變更",
    "Your email address on %s was changed by an administrator." : "您在 %s 的電子郵件地址已被管理員變更",
    "Email address for %1$s changed on %2$s" : "%1$s 的電子郵件地址在 %2$s 變更",
    "Email address changed for %s" : "%s 的電子郵件地址已變更",
    "The new email address is %s" : "新的電子郵件地址為 %s",
    "Your %s account was created" : "您的 %s 帳號已經建立",
    "Welcome aboard" : "歡迎加入",
    "Welcome aboard %s" : "歡迎加入 %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "歡迎使用您的 %s 帳戶，您可以加入、保存、分享您的資料",
    "Your username is: %s" : "您的使用者名稱為： %s",
    "Set your password" : "設定您的密碼",
    "Go to %s" : "前往 %s",
    "Install Client" : "安裝客戶端程式",
    "Unlimited" : "無限制",
    "Limit to groups" : "限制給特定群組",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方應用程序是由社區內部和內部開發的。 它們提供核心功能，並可在正式成品使用。",
    "Official" : "官方",
    "Remove" : "移除",
    "Disable" : "停用",
    "All" : "所有",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最低的Nextcloud版本，未來將會產生問題。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最高的Nextcloud版本，未來將會產生問題。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "這個應用程式無法被安裝，因為欠缺下列相依套件：",
    "View in store" : "在商店中檢視",
    "Visit website" : "開啟網站",
    "Report a bug" : "回報問題",
    "User documentation" : "用戶說明文件",
    "Admin documentation" : "管理者文件",
    "Developer documentation" : "開發者說明文件",
    "No apps found for your version" : "沒有找到適合您的版本的應用程式",
    "Enable all" : "全部啟用",
    "Enable" : "啟用",
    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
    "Allow filesystem access" : "允許檔案系統的存取",
    "Revoke" : "撤銷",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "Sync client - {os}" : "同步客戶端 - {os}",
    "This session" : "目前的工作階段",
    "Device" : "裝置",
    "Last activity" : "上次活動",
    "Web, desktop and mobile clients currently logged in to your account." : "目前登入您的帳號的網頁、桌面和行動裝置客戶端",
    "Error while creating device token" : "建立裝置 token 時發生錯誤",
    "Error while deleting the token" : "刪除 token 時發生錯誤",
    "App name" : "應用程式名稱",
    "Create new app password" : "建立新的應用程式密碼",
    "Use the credentials below to configure your app or device." : "請使用下方的登入資訊來設定您的應用程式或是裝置",
    "For security reasons this password will only be shown once." : "基於安全性考量，這個密碼只會顯示一次",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Done" : "完成",
    "Copied!" : "已複製",
    "Copy" : "複製",
    "New password" : "新密碼",
    "{size} used" : "{size} 已使用",
    "Email" : "信箱",
    "Group admin for" : "群組管理員",
    "Quota" : "容量限制",
    "Language" : "語言",
    "Storage location" : "儲存位址",
    "User backend" : "使用者資料後端",
    "Default quota" : "預設儲存容量限制",
    "Your apps" : "您的應用程式",
    "Disabled apps" : "已停用應用程式",
    "Updates" : "更新",
    "App bundles" : "應用程式套裝",
    "Show last login" : "顯示上次登入時間",
    "Show user backend" : "顯示使用者資料後端",
    "Admins" : "管理者",
    "Everyone" : "所有人",
    "Add group" : "新增群組",
    "Error: This app can not be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
    "SSL Root Certificates" : "SSL 根憑證",
    "Common Name" : "Common Name",
    "Valid until" : "到期日",
    "Issued By" : "發行者：",
    "Valid until %s" : "有效至 %s",
    "Import root certificate" : "匯入根憑證",
    "Administrator documentation" : "管理者說明文件",
    "Forum" : "論壇",
    "None" : "無",
    "Login" : "登入",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "郵件伺服器",
    "Open documentation" : "開啟說明文件",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "設定伺服器可以寄送電子郵件非常重要，使用者通知和密碼重設將會需要",
    "Send mode" : "寄送模式",
    "Encryption" : "加密",
    "From address" : "寄件地址",
    "mail" : "電子郵件",
    "Authentication method" : "認證方式",
    "Authentication required" : "需要認證",
    "Server address" : "伺服器位址",
    "Port" : "連接埠",
    "Credentials" : "帳密",
    "SMTP Username" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Test email settings" : "測試郵件設定",
    "Send email" : "寄送郵件",
    "Security & setup warnings" : "安全及設定警告",
    "All checks passed." : "所有檢查正常",
    "Version" : "版本",
    "Server-side encryption" : "伺服器端加密",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "伺服器端加密可以加密所有上傳到此伺服器的檔案，但這會讓檔案操作時間增加，降低效能，請審慎評估後再啟用。",
    "Enable server-side encryption" : "啟用伺服器端加密",
    "Please read carefully before activating server-side encryption: " : "在您啟動伺服器端加密之前，請仔細閱讀：",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密模式啟動，從各地上傳到伺服器端的檔案都會被加密，若日後要停用加密，需要加密模組的支援，而且所有的設定（例如：還原金鑰）都正確",
    "Be aware that encryption always increases the file size." : "請注意，加密一定會增加檔案的大小",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定時備份您的資料沒有壞處，若您有啟用加密，請確保您也有備份加密金鑰",
    "This is the final warning: Do you really want to enable encryption?" : "這是最後的警告：請問您真的要開啟加密模式？",
    "Enable encryption" : "啟用加密",
    "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式清單中啟用加密模組",
    "Select default encryption module:" : "選擇預設的加密模組：",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : " 您需要遷移您的加密金鑰從舊版的加密 (ownCloud <= 8.0) 到新版，請啟用「預設加密模組」並執行 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : " 您需要遷移您的加密金鑰從舊版的加密 (ownCloud <= 8.0) 到新版",
    "Start migration" : "開始遷移",
    "Background jobs" : "背景工作",
    "Last job ran %s." : "上次背景工作執行於 %s",
    "Last job execution ran %s. Something seems wrong." : "上次背景工作執行於 %s ，似乎有點問題",
    "Background job didn’t run yet!" : "背景工作從未執行！",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "為了獲得最佳的效能，設定背景工作非常重要，對於比較大的服務來說，建議使用 Cron 設定，請查閱說明文件以獲得更多資訊。",
    "Execute one task with each page loaded" : "每個頁面載入時執行",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統使用者 \"%s\" 來執行",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件，請查閱 {linkstart}PHP 說明文件{linkend} 以獲得更多細節。",
    "Sharing" : "分享",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "系統管理員可以微調分享行為，請查閱說明文件以獲得更多資訊。",
    "Allow apps to use the Share API" : "允許 apps 使用分享 API",
    "Allow users to share via link" : "允許使用者透過連結分享",
    "Allow public uploads" : "允許公開上傳",
    "Always ask for a password" : "總是詢問密碼",
    "Enforce password protection" : "強制分享連結使用密碼保護",
    "Set default expiration date" : "設定預設到期日",
    "Expire after " : "在什麼時候過期",
    "days" : "天",
    "Enforce expiration date" : "強制分享連結設定到期日",
    "Allow resharing" : "允許轉貼分享",
    "Allow sharing with groups" : "允許與群組分享",
    "Restrict users to only share with users in their groups" : "限制使用者只能分享給群組裡的其他使用者",
    "Exclude groups from sharing" : "禁止特定群組分享檔案",
    "These groups will still be able to receive shares, but not to initiate them." : "這些群組仍然能接受其他人的分享，但是沒有辦法發起分享",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "允許使用者名稱自動補齊在分享對話框，如果停用這個功能，必須輸入完整的使用者名稱或電子郵件地址",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "在公開的檔案連結和上傳頁面顯示免責聲明（只有在檔案清單隱藏的時候才會顯示）",
    "This text will be shown on the public link upload page when the file list is hidden." : "這段文字會在公開檔案上傳頁面檔案清單被隱藏的時候顯示",
    "Personal" : "個人",
    "Administration" : "管理",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud 社群{linkclose}開發，{githubopen}原始碼{linkclose}以 {licenseopen}AGPL 授權{linkclose}釋出",
    "Like our Facebook page" : "到我們的 Facebook 頁面按讚",
    "Follow us on Twitter" : "在 Twitter 上面追蹤我們",
    "Check out our blog" : "逛逛我們的部落格",
    "Subscribe to our newsletter" : "訂閱我們的電子報",
    "Profile picture" : "大頭貼照",
    "Upload new" : "上傳新的",
    "Select from Files" : "從雲端檔案選擇",
    "Remove image" : "移除圖片",
    "png or jpg, max. 20 MB" : "png 或 jpg ，最大 20 MB",
    "Picture provided by original account" : "原本的帳戶提供的圖片",
    "Cancel" : "取消",
    "Choose as profile picture" : "設定為大頭貼照",
    "Full name" : "全名",
    "No display name set" : "未設定顯示名稱",
    "Your email address" : "您的電子郵件信箱",
    "No email address set" : "未設定電子郵件信箱",
    "For password reset and notifications" : "用於密碼重設和通知信件",
    "Phone number" : "電話號碼",
    "Your phone number" : "您的電話號碼",
    "Address" : "地址",
    "Your postal address" : "您的郵遞地址",
    "Website" : "網站",
    "Link https://…" : "連結 https://...",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter 用戶名 @...",
    "Help translate" : "幫助翻譯",
    "Locale" : "所在地",
    "Current password" : "目前密碼",
    "Change password" : "變更密碼",
    "Store credentials" : "儲存帳密",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php 已經在一個 webcron 服務中註冊，每 15 分鐘將會透過 HTTP 呼叫 cron.php",
    "Use system cron service to call the cron.php file every 15 minutes." : "使用系統的 cron 服務來每隔 15 分鐘呼叫 cron.php"
},
"nplurals=1; plural=0;");
